==> gchempaint-0.5.2.tar.bz2: gchempaint-0.5.2/lib/settings.cc <==
// -*- C++ -*-

/* 
 * GChemPaint library
 * settings.cc 
 *
 * Copyright (C) 2001-2004
 *
 * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#include "gchempaint-config.h"
#include "settings.h"
double DefaultBondLength = 140;
double DefaultBondDist = 20;
double DefaultBondWidth = 4.0;
double DefaultArrowLength = 200;
double DefaultArrowHeadA=24.0;
double DefaultArrowHeadB=32.0;
double DefaultArrowHeadC=16.0;
double DefaultArrowDist = 20;
double DefaultHashWidth = 4.0;
double DefaultHashDist = 8.0;
double DefaultStereoBondWidth = 20.0;
double DefaultZoomFactor = 0.25;
double DefaultPadding = 8.0;
double DefaultArrowPadding = 64.0;
double DefaultSignPadding = 10.0;
gchar* Color = "black";
gchar* DeleteColor = "red";
gchar* AddColor = "green";
gchar* SelectColor = "cyan";
gchar* DefaultFontFamily ="Bitstream Vera Sans";
PangoStyle DefaultFontStyle = PANGO_STYLE_NORMAL;
PangoWeight DefaultFontWeight = PANGO_WEIGHT_NORMAL;
PangoVariant DefaultFontVariant = PANGO_VARIANT_NORMAL;
PangoStretch DefaultFontStretch = PANGO_STRETCH_NORMAL;
gint DefaultFontSize = 12 * PANGO_SCALE;
unsigned MaxStackSize = 0;//infinite size authorized for undo:redo stacks

==> gchempaint-0.5.5.tar.bz2: gchempaint-0.5.5/lib/settings.cc <==
// -*- C++ -*-

/* 
 * GChemPaint library
 * settings.cc 
 *
 * Copyright (C) 2001-2004
 *
 * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#include "gchempaint-config.h"
#include "settings.h"
double DefaultBondLength = 140;
double DefaultBondDist = 20;
double DefaultBondWidth = 4.0;
double DefaultArrowLength = 200;
double DefaultArrowHeadA=24.0;
double DefaultArrowHeadB=32.0;
double DefaultArrowHeadC=16.0;
double DefaultArrowDist = 20;
double DefaultHashWidth = 4.0;
double DefaultHashDist = 8.0;
double DefaultStereoBondWidth = 20.0;
double DefaultZoomFactor = 0.25;
double DefaultPadding = 8.0;
double DefaultArrowPadding = 64.0;
double DefaultStoichiometryPadding = 4.;
double DefaultObjectPadding = 64.0;
double DefaultSignPadding = 32.0;
gchar* Color = "black";
gchar* DeleteColor = "red";
gchar* AddColor = "green";
gchar* SelectColor = "cyan";
gchar* DefaultFontFamily ="Bitstream Vera Sans";
PangoStyle DefaultFontStyle = PANGO_STYLE_NORMAL;
PangoWeight DefaultFontWeight = PANGO_WEIGHT_NORMAL;
PangoVariant DefaultFontVariant = PANGO_VARIANT_NORMAL;
PangoStretch DefaultFontStretch = PANGO_STRETCH_NORMAL;
gint DefaultFontSize = 12 * PANGO_SCALE;
unsigned MaxStackSize = 0;//infinite size authorized for undo:redo stacks
